Core APIs
=========

.. toctree::
   :maxdepth: 1

   vreg.rst
   appobject.rst
   selectors.rst
   dbapi.rst


:mod:`Configuration <cubicweb.cwconfig>`
----------------------------------------

.. automodule:: cubicweb.cwconfig
   :members:
